<!-- ------------------- generated docs start ------------------- -->
# twitch-dl env

Print environment information for inclusion in bug reports.

### USAGE

```
twitch-dl env [OPTIONS]
```

<!-- ------------------- generated docs end ------------------- -->

Includes the twitch-dl version, platform details and python version. Does not
include any personal information.

On Linux this may return something like:

```
twitch-dl 1.21.0
Platform: Linux-5.10.0-10-amd64-x86_64-with-glibc2.31
Python 3.9.2 (default, Feb 28 2021, 17:03:44) [GCC 10.2.1 20210110]
```

On Windows:

```
twitch-dl 1.21.0
Platform: Windows-10-10.0.19041-SP0
Python 3.9.4 (tags/v3.9.4:1f2e308, Apr 6 2021, 13:40:21) [MSC v.1928 64 bit (AMD64)]
```